<!DOCTYPE html>
<html>
<head>
    <title>Catalogo Prodotti</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <style>
        body {
            font-family: Arial, sans-serif;
            padding: 10px;
            margin: 0;
            background-color: #f2f2f2;
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        h1 {
            text-align: center;
            margin-top: 0;
            color: #333;
        }

        .counter {
            text-align: center;
            margin-bottom: 20px;
            font-weight: bold;
        }

        .product-container {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 20px;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            background-color: #f9f9f9;
        }

        .product-image {
            max-width: 200px;
            max-height: 100px;
            width: auto;
            height: auto;
            margin-right: 20px;
        }

        .product-details {
            flex: 1;
        }

        .product-name {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 5px;
            color: #333;
        }

        .product-category {
            font-style: italic;
            color: #888;
            margin-bottom: 5px;
        }

        .product-description {
            margin-bottom: 10px;
            color: #555;
        }

        .product-price {
            font-weight: bold;
            color: #00a0d2;
            display: flex;
            align-items: center;
        }

        .product-price::before {
            content: '\20AC';
            margin-right: 3px;
        }

        .search-bar {
            margin-bottom: 20px;
        }

        .search-bar input[type="text"] {
            width: 200px;
            padding: 5px;
        }

        .search-bar button {
            padding: 5px 10px;
            background-color: #00a0d2;
            color: #fff;
            border: none;
            cursor: pointer;
        }

        .category-buttons {
            text-align: center;
            margin-bottom: 20px;
        }

        .category-buttons a {
            display: inline-block;
            margin-right: 10px;
            padding: 5px 10px;
            background-color: #00a0d2;
            color: #fff;
            text-decoration: none;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Catalogo Prodotti</h1>

        <div class="category-buttons">
            <a href="accessori.php">Accessori</a>
            <a href="dispositivo.php">Dispositivo</a>
            <a href="liquido.php">Liquido</a>
            <a href="resistenza.php">Resistenza</a>
            <a href="TPD.php">TPD</a>
        </div>

        <div class="search-bar">
            <form method="GET" action="">
                <label for="search">Cerca per nome tra tutte le categorie:</label>
                <input type="text" id="search" name="search" placeholder="Inserisci il nome del prodotto">
                <button type="submit">Cerca</button>
            </form>
        </div>

        <?php
        $config = [
            'db_engine' => 'mysql',
            'db_host' => 'localhost',
            'db_name' => 'app',
            'db_user' => 'smilesmoke',
            'db_password' => 'palermo9898',
        ];

        $db_config = $config['db_engine'] . ":host=" . $config['db_host'] . ";dbname=" . $config['db_name'];
        $host = $config['db_host'];
        $db = $config['db_name'];
        $user = $config['db_user'];
        $password = $config['db_password'];

        try {
            $pdo = new PDO($db_config, $config['db_user'], $config['db_password'], [
                PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8"
            ]);

            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            $pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
        } catch (PDOException $e) {
            exit("Impossibile connettersi al database: " . $e->getMessage());
        }

        if (isset($_GET['search']) && !empty($_GET['search'])) {
            $searchTerm = '%' . $_GET['search'] . '%';
            $query = "SELECT BARCODE, NOME, DESCRIZIONE, CATEGORIA, PREZZO, IMG FROM PRODOTTO WHERE NOME LIKE :searchTerm ORDER BY ID DESC";
            $stmt = $pdo->prepare($query);
            $stmt->bindParam(':searchTerm', $searchTerm, PDO::PARAM_STR);
        } else {
            $query = "SELECT BARCODE, NOME, DESCRIZIONE, CATEGORIA, PREZZO, IMG FROM PRODOTTO ORDER BY ID DESC";
            $stmt = $pdo->prepare($query);
        }

        $stmt->execute();
        $prodotti = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $categories = ['ACCESSORI', 'LIQUIDO', 'RESISTENZA', 'TPD', 'DISPOSITIVO'];

        echo '<div class="counter">Prodotti totali: ' . count($prodotti) . '</div>';

        foreach ($prodotti as $prodotto) {
            $barcode = $prodotto['BARCODE'];
            $nome = $prodotto['NOME'];
            $descrizione = $prodotto['DESCRIZIONE'];
            $categoria = $prodotto['CATEGORIA'];
            $prezzo = $prodotto['PREZZO'];
            $img = $prodotto['IMG'];

            if (!in_array($categoria, $categories)) {
                continue;
            }
        ?>
            <div class="product-container">
                <img src="<?php echo $img; ?>" alt="Immagine Prodotto" class="product-image">
                <div class="product-details">
                    <div class="product-name"><?php echo $nome; ?></div>
                    <div class="product-category"><?php echo $categoria; ?></div>
                    <div class="product-description"><?php echo $descrizione; ?></div>
                    <div class="product-price"><?php echo $prezzo; ?></div>
                </div>
            </div>
        <?php
        }
        ?>

    </div>
</body>
</html>
